summaryrefslogtreecommitdiffstats
path: root/crawl-ref/source/stuff.cc
diff options
context:
space:
mode:
Diffstat (limited to 'crawl-ref/source/stuff.cc')
-rw-r--r--crawl-ref/source/stuff.cc11
1 files changed, 9 insertions, 2 deletions
diff --git a/crawl-ref/source/stuff.cc b/crawl-ref/source/stuff.cc
index 1bbba85a91..768b10f762 100644
--- a/crawl-ref/source/stuff.cc
+++ b/crawl-ref/source/stuff.cc
@@ -368,8 +368,15 @@ static bool tag_follower_at(const coord_def &pos)
if (!mons_friendly(fmenv))
return (false);
- // Orcs will follow Beogh worshippers.
- if (you.religion != GOD_BEOGH || !is_follower(fmenv))
+ // Non-mindless undead will follow Yredelemnul worshippers, and
+ // orcs will follow Beogh worshippers.
+ if (you.religion != GOD_YREDELEMNUL && you.religion != GOD_BEOGH)
+ return (false);
+
+ if (you.religion == GOD_YREDELEMNUL && mons_intel(fmenv) <= I_PLANT)
+ return (false);
+
+ if (!is_follower(fmenv))
return (false);
}